@@ -4,7 +4,7 @@ use Moose;
 use Term::Readline;
 use Data::Dumper;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'router' => (
@@ -46,8 +46,22 @@ Path::Router::Shell - An interactive shell for testing router configurations
 
 =head1 SYNOPSIS
 
+  #!/usr/bin/perl
+  
+  use strict;
+  use warnings;
+  
+  use My::App::Router;
+  use Path::Router::Shell;
+  
+  Path::Router::Shell->new(router => My::App::Router->new)->shell;
+
 =head1 DESCRIPTION
 
+This is a tool for helping test the routing in your applications, so 
+you simply write a small script like showing in the SYNOPSIS and then 
+you can use it to test new routes or debug routing issues, etc etc etc. 
+
 =head1 METHODS
 
 =over 4
